==> eiffelstudio-18.01.10.1424.tar: F_code/C5/in211.c <==
/*
 * Code for class INTERNAL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in211.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INTERNAL}.type_name */
EIF_REFERENCE F455_4293 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = F1_5(arg1);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5962[Dtype(tr1)-869])(RTCW(tr1));
	Result = F995_8135(RTCW(tr1));
	RTLE;
	return Result;
}

/* {INTERNAL}.dynamic_type */
EIF_INTEGER_32 F455_4294 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = RTOSCF(4346,F455_4346,(Current));
	tr2 = RTCCL(arg1);
	F460_4465(RTCW(tr1), tr2);
	Result = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(4346,F455_4346,(Current)))+ _LNGOFF_1_0_0_0_);
	RTLE;
	return Result;
}

/* {INTERNAL}.field */
EIF_REFERENCE F455_4297 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,tr2);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTOSCF(4346,F455_4346,(Current));
	tr2 = RTCCL(arg2);
	F460_4465(RTCW(tr1), tr2);
	tr1 = RTOSCF(4346,F455_4346,(Current));
	Result = F453_4192(RTCW(tr1), arg1);
	RTLE;
	return Result;
}

/* {INTERNAL}.field_name */
EIF_REFERENCE F455_4299 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg2);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	tr1 = RTCCL(arg2);
	ti4_1 = F455_4294(Current, tr1);
	Result = F454_4274(Current, arg1, ti4_1);
	RTLE;
	return Result;
}

/* {INTERNAL}.field_count */
EIF_INTEGER_32 F455_4340 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = RTOSCF(4346,F455_4346,(Current));
	tr2 = RTCCL(arg1);
	F460_4465(RTCW(tr1), tr2);
	Result = F453_4246(RTCV(RTOSCF(4346,F455_4346,(Current))));
	RTLE;
	return Result;
}

/* {INTERNAL}.reflected_object */
static EIF_REFERENCE F455_4346_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4346);
#define Result RTOSR(4346)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(459, 0x01).id, 459, _OBJSIZ_1_0_0_2_0_0_0_0_);
	F460_4456(RTCW(tr1), Current);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4346);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F455_4346 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4346,F455_4346_body,(Current));
}

void EIF_Minit211 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C5/in211.c <==
/*
 * Code for class INTERNAL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in211.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INTERNAL}.type_name */
EIF_REFERENCE F455_4293 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = F1_5(arg1);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5964[Dtype(tr1)-869])(RTCW(tr1));
	Result = F995_8137(RTCW(tr1));
	RTLE;
	return Result;
}

/* {INTERNAL}.dynamic_type */
EIF_INTEGER_32 F455_4294 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = RTOSCF(4346,F455_4346,(Current));
	tr2 = RTCCL(arg1);
	F460_4465(RTCW(tr1), tr2);
	Result = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(4346,F455_4346,(Current)))+ _LNGOFF_1_0_0_0_);
	RTLE;
	return Result;
}

/* {INTERNAL}.field */
EIF_REFERENCE F455_4297 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,tr2);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTOSCF(4346,F455_4346,(Current));
	tr2 = RTCCL(arg2);
	F460_4465(RTCW(tr1), tr2);
	tr1 = RTOSCF(4346,F455_4346,(Current));
	Result = F453_4192(RTCW(tr1), arg1);
	RTLE;
	return Result;
}

/* {INTERNAL}.field_name */
EIF_REFERENCE F455_4299 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg2);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	tr1 = RTCCL(arg2);
	ti4_1 = F455_4294(Current, tr1);
	Result = F454_4274(Current, arg1, ti4_1);
	RTLE;
	return Result;
}

/* {INTERNAL}.field_count */
EIF_INTEGER_32 F455_4340 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = RTOSCF(4346,F455_4346,(Current));
	tr2 = RTCCL(arg1);
	F460_4465(RTCW(tr1), tr2);
	Result = F453_4246(RTCV(RTOSCF(4346,F455_4346,(Current))));
	RTLE;
	return Result;
}

/* {INTERNAL}.reflected_object */
static EIF_REFERENCE F455_4346_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (4346);
#define Result RTOSR(4346)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(459, 0x01).id, 459, _OBJSIZ_1_0_0_2_0_0_0_0_);
	tr2 = RTMS_EX_H("",0,0);
	F460_4456(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4346);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F455_4346 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4346,F455_4346_body,(Current));
}

void EIF_Minit211 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
